==> LBE_1.8.0.zip: LBE/doc/LBE.R <==
###################################################
### chunk number 1: 
###################################################
library(LBE)
data(golub.pval)


###################################################
### chunk number 2: 
###################################################
LBE.res <- LBE(golub.pval)


###################################################
### chunk number 3: 
###################################################
#LBE.res <- LBE(golub.pval)
names(LBE.res)
LBE.res$pi0; LBE.res$pi0.ci; LBE.res$ci.level
LBE.res2 <- LBE(golub.pval, ci.level=0.8,plot.type="none")
LBE.res2$pi0.ci; LBE.res2$ci.level


###################################################
### chunk number 4: 
###################################################
LBE.res3 <- LBE(golub.pval, FDR.level=0.1,plot.type="none")
LBE.res3$qvalues[1:10]
LBE.res3$n.significant


###################################################
### chunk number 5: 
###################################################
LBE.res4 <- LBE(golub.pval,FDR.level=NA,n.significant=300)


###################################################
### chunk number 6: 
###################################################
LBE.res4$qvalues[1:10]


###################################################
### chunk number 7: 
###################################################
LBE.res5 <- LBE(golub.pval,a=2,l=NA,plot.type="none")
LBE.res5$a; LBE.res5$l; LBE.res5$pi0; LBE.res5$pi0.ci; LBE.res5$n.significant
LBE.res6 <- LBE(golub.pval,a=NA,l=0.1,plot.type="none")
LBE.res6$a; LBE.res6$l; LBE.res6$pi0; LBE.res6$pi0.ci; LBE.res6$n.significant
LBE.res7 <- LBE(golub.pval,a=-1,l=NA,plot.type="none")
LBE.res7$a; LBE.res7$l; LBE.res7$pi0; LBE.res7$pi0.ci; LBE.res7$n.significant


###################################################
### chunk number 8: 
###################################################
LBEplot(LBE.res,plot.type="multiple")


###################################################
### chunk number 9: 
###################################################
LBEa(length(golub.pval),l=0.1)


###################################################
### chunk number 10: 
###################################################
LBEsummary(LBE.res)


###################################################
### chunk number 11: 
###################################################
LBEwrite(LBE.res)


###################################################
### chunk number 12: 
###################################################
library(qvalue)
qvalue.res <- qvalue(golub.pval)
qsummary(qvalue.res)
LBEsummary(LBE.res)

==> LBE_1.18.0.zip: LBE/doc/LBE.R <==
###################################################
### chunk number 1: 
###################################################
#line 68 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpG8MFe7/R.INSTALL4ff318b/LBE/inst/doc/LBE.Rnw"
library(LBE)
data(golub.pval)


###################################################
### chunk number 2: 
###################################################
#line 107 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpG8MFe7/R.INSTALL4ff318b/LBE/inst/doc/LBE.Rnw"
LBE.res <- LBE(golub.pval)


###################################################
### chunk number 3: 
###################################################
#line 113 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpG8MFe7/R.INSTALL4ff318b/LBE/inst/doc/LBE.Rnw"
#LBE.res <- LBE(golub.pval)
names(LBE.res)
LBE.res$pi0; LBE.res$pi0.ci; LBE.res$ci.level
LBE.res2 <- LBE(golub.pval, ci.level=0.8,plot.type="none")
LBE.res2$pi0.ci; LBE.res2$ci.level


###################################################
### chunk number 4: 
###################################################
#line 129 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpG8MFe7/R.INSTALL4ff318b/LBE/inst/doc/LBE.Rnw"
LBE.res3 <- LBE(golub.pval, FDR.level=0.1,plot.type="none")
LBE.res3$qvalues[1:10]
LBE.res3$n.significant


###################################################
### chunk number 5: 
###################################################
#line 136 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpG8MFe7/R.INSTALL4ff318b/LBE/inst/doc/LBE.Rnw"
LBE.res4 <- LBE(golub.pval,FDR.level=NA,n.significant=300)


###################################################
### chunk number 6: 
###################################################
#line 142 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpG8MFe7/R.INSTALL4ff318b/LBE/inst/doc/LBE.Rnw"
LBE.res4$qvalues[1:10]


###################################################
### chunk number 7: 
###################################################
#line 156 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpG8MFe7/R.INSTALL4ff318b/LBE/inst/doc/LBE.Rnw"
LBE.res5 <- LBE(golub.pval,a=2,l=NA,plot.type="none")
LBE.res5$a; LBE.res5$l; LBE.res5$pi0; LBE.res5$pi0.ci; LBE.res5$n.significant
LBE.res6 <- LBE(golub.pval,a=NA,l=0.1,plot.type="none")
LBE.res6$a; LBE.res6$l; LBE.res6$pi0; LBE.res6$pi0.ci; LBE.res6$n.significant
LBE.res7 <- LBE(golub.pval,a=-1,l=NA,plot.type="none")
LBE.res7$a; LBE.res7$l; LBE.res7$pi0; LBE.res7$pi0.ci; LBE.res7$n.significant


###################################################
### chunk number 8: 
###################################################
#line 174 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpG8MFe7/R.INSTALL4ff318b/LBE/inst/doc/LBE.Rnw"
LBEplot(LBE.res,plot.type="multiple")


###################################################
### chunk number 9: 
###################################################
#line 188 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpG8MFe7/R.INSTALL4ff318b/LBE/inst/doc/LBE.Rnw"
LBEa(length(golub.pval),l=0.1)


###################################################
### chunk number 10: 
###################################################
#line 199 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpG8MFe7/R.INSTALL4ff318b/LBE/inst/doc/LBE.Rnw"
LBEsummary(LBE.res)


###################################################
### chunk number 11: 
###################################################
#line 207 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpG8MFe7/R.INSTALL4ff318b/LBE/inst/doc/LBE.Rnw"
LBEwrite(LBE.res)


###################################################
### chunk number 12: 
###################################################
#line 220 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpG8MFe7/R.INSTALL4ff318b/LBE/inst/doc/LBE.Rnw"
library(qvalue)
qvalue.res <- qvalue(golub.pval)
qsummary(qvalue.res)
LBEsummary(LBE.res)
